@@ -14,7 +14,7 @@ class CompositeLogger(LoggerImpl):
     def log(self, message: dict, option: dict = {}):
         mergedMessage = {}
         if len(self.config["defaults"]) > 0:
-            mergedMessage: dict = self.config["defaults"]
+            mergedMessage: dict = self.config["defaults"].copy()
             for k, v in mergedMessage.items():
                 if callable(v):
                     v()
